==> native2ascii-maven-plugin-2.0.1-sources.jar: org/codehaus/mojo/native2ascii/PropertyEscaper.java <==
/*
 * The MIT License
 * Copyright (c) 2007 The Codehaus
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package org.codehaus.mojo.native2ascii;

import org.apache.commons.lang3.text.translate.UnicodeEscaper;


/**
 * Uses {@link UnicodeEscaper} to translate strings with bytes over \u007F to unicode.
 *
 * @author David Matějček
 */
public class PropertyEscaper extends UnicodeEscaper {

  /**
   * Constructor using {@link UnicodeEscaper#UnicodeEscaper(int, int, boolean)}
   */
  public PropertyEscaper() {
    super(0x007F, Integer.MAX_VALUE, true);
  }

}

==> native2ascii-maven-plugin-2.1.0-sources.jar: org/codehaus/mojo/native2ascii/PropertyEscaper.java <==
/*
 * The MIT License
 * Copyright (c) 2014-2022 MojoHaus
 * Copyright (c) 2007 The Codehaus
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package org.codehaus.mojo.native2ascii;

import org.apache.commons.text.translate.UnicodeEscaper;

/**
 * Uses {@link UnicodeEscaper} to translate strings with bytes over \u007F to unicode.
 *
 * @author David Matějček
 */
public class PropertyEscaper extends UnicodeEscaper {

  /**
   * Constructor using {@link UnicodeEscaper#UnicodeEscaper(int, int, boolean)}
   */
  public PropertyEscaper() {
    super(0x007F, Integer.MAX_VALUE, true);
  }

}
